# Automations with Scripts
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/automations-with-scripts#overview)
  * [Technical Details](https://help.sap.com/docs/leanix/ea/automations-with-scripts#technical-details)
  * [Limitations for Fields](https://help.sap.com/docs/leanix/ea/automations-with-scripts#limitations-for-fields)
  * [Creating an Automation with a Script](https://help.sap.com/docs/leanix/ea/automations-with-scripts#creating-an-automation-with-a-script)
  * [Calling API Endpoints from Scripts](https://help.sap.com/docs/leanix/ea/automations-with-scripts#calling-api-endpoints-from-scripts)
  * [Code Configurations and Execution Log](https://help.sap.com/docs/leanix/ea/automations-with-scripts#code-configurations-and-execution-log)
  * [Canceling Subsequent Actions in an Automation](https://help.sap.com/docs/leanix/ea/automations-with-scripts#canceling-subsequent-actions-in-an-automation)
  * [Examples](https://help.sap.com/docs/leanix/ea/automations-with-scripts#examples)


Use automations with scripts to update fact sheet fields or call SAP LeanIX APIs. Define the script logic in a script editor in SAP LeanIX.
